Workflow
--------

The workflow component is responsible for converting a Gordo config into
an Argo workflow which then runs the various components in order to build
and serve the ML models.


Normalized Config
=================
.. automodule:: gordo.workflow.config_elements.normalized_config
    :members:
    :undoc-members:
    :show-inheritance:

Workflow Generator
==================

Workflow loading/processing functionality to help the CLI 'workflow' sub-command.

.. automodule:: gordo.workflow.workflow_generator.workflow_generator
    :members:
    :undoc-members:
    :show-inheritance:

Helpers
=======
.. automodule:: gordo.workflow.workflow_generator.helpers
    :members:
    :undoc-members:
    :show-inheritance:

